/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.bundu.bezugswst;

import org.apache.log4j.Logger;
import org.dive4elements.river.artifacts.common.AbstractCalculationExportableResult;
import org.dive4elements.river.artifacts.common.AbstractCommonExporter;
import org.dive4elements.river.artifacts.common.ExportContextCSV;
import org.dive4elements.river.artifacts.common.ExportContextPDF;
import org.dive4elements.river.artifacts.common.JasperDesigner;
import org.dive4elements.river.artifacts.common.MetaAndTableJRDataSource;

/**
 * Generates different output formats (wst, csv, pdf) of data that resulted from
 * a waterlevel computation.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class BunduWstExporter extends AbstractCommonExporter<AbstractCalculationExportableResult, BezugswstCalculationResults> {

    /** The log used in this exporter. */
    private static Logger log = Logger.getLogger(BunduWstExporter.class);

    @Override
    protected void writeCSVGlobalMetadata(final ExportContextCSV exportContext, final BezugswstCalculationResults results) {
        exportContext.writeCSVGlobalMetadataDefaults();
    }

    @Override
    protected void writePDFGlobalMetadata(final ExportContextPDF exportContext, final MetaAndTableJRDataSource source) {
        exportContext.addJRMetaDataForModules(source);

    }

    @Override
    protected void configureDesign(final AbstractCalculationExportableResult result, final JasperDesigner design) {
        if (result instanceof BezugswstMissVolCalculationResult1 // || result intanceof BezugswstMiss...2,3 TODO

        ) {
            design.getSource().addMetaData("bezugswst_result_header", result.getLabel()); // globalMeta? wrong place. only one result expected, so it works
        }
    }
}